@@ -1061,6 +1061,8 @@ void map_deselect_if_zoom_below_zoom_max(map_t *map) {
     }
 }
 
+#define GPS_RADIUS_LIMIT  3.0
+    
 void map_set_zoom(map_t *map, double zoom, 
 		  gboolean update_scroll_offsets) {
   gboolean at_zoom_limit = 0;
@@ -1086,6 +1088,16 @@ void map_set_zoom(map_t *map, double zoom,
 		      &map->state->scroll_offset.x,
 		      &map->state->scroll_offset.y);
   }
+
+  if(map->appdata->track.gps_item) {
+    float radius = map->style->track.width/2.0;
+    if(zoom < GPS_RADIUS_LIMIT) {
+      radius *= GPS_RADIUS_LIMIT;
+      radius /= zoom;
+      
+      canvas_item_set_radius(map->appdata->track.gps_item, radius); 
+    }
+  }
 }
 
 static gboolean map_scroll_event(GtkWidget *widget, GdkEventScroll *event,
@@ -2263,9 +2275,16 @@ void map_track_pos(appdata_t *appdata, pos_t *pos) {
     lpos_t lpos;
     pos2lpos(appdata->osm->bounds, pos, &lpos);
 
+    float radius = appdata->map->style->track.width/2.0;
+    gdouble zoom = canvas_get_zoom(appdata->map->canvas);
+    if(zoom < GPS_RADIUS_LIMIT) {
+      radius *= GPS_RADIUS_LIMIT;
+      radius /= zoom;
+    }
+
     appdata->track.gps_item = 
       canvas_circle_new(appdata->map->canvas, CANVAS_GROUP_GPS, 
-	lpos.x, lpos.y, appdata->map->style->track.width/2.0, 0, 
+			lpos.x, lpos.y, radius, 0, 
 			appdata->map->style->track.gps_color, NO_COLOR);
   }
 }
