@@ -379,9 +379,6 @@ static gboolean osm_file_exists(char *path, char *name) {
 }
 
 static void view_selected(select_context_t *context, project_t *project) {
-  list_button_enable(context->list, LIST_BUTTON_REMOVE, project != NULL);
-  list_button_enable(context->list, LIST_BUTTON_EDIT, project != NULL);
-
   /* check if the selected project also has a valid osm file */
   gtk_dialog_set_response_sensitive(GTK_DIALOG(context->dialog), 
       GTK_RESPONSE_ACCEPT, 
@@ -412,8 +409,7 @@ static project_t *project_get_selected(GtkWidget *list) {
   GtkTreeModel     *model;
   GtkTreeIter       iter;
 
-  GtkTreeSelection *selection = list_get_selection(list);
-  g_assert(gtk_tree_selection_get_selected(selection, &model, &iter));
+  g_assert(list_get_selected(list, &model, &iter));
   gtk_tree_model_get(model, &iter, PROJECT_COL_DATA, &project, -1);
 
   return project;
@@ -796,8 +792,9 @@ static GtkWidget *project_list_widget(select_context_t *context) {
   list_set_store(context->list, store);
   g_object_unref(store);
 
-  list_set_static_buttons(context->list, TRUE, G_CALLBACK(on_project_new),
-	  G_CALLBACK(on_project_edit), G_CALLBACK(on_project_delete), context);
+  list_set_static_buttons(context->list, LIST_BTN_NEW | LIST_BTN_BIG, 
+	  G_CALLBACK(on_project_new), G_CALLBACK(on_project_edit), 
+	  G_CALLBACK(on_project_delete), context);
 
   return context->list;
 }
@@ -818,6 +815,8 @@ static char *project_select(appdata_t *appdata) {
           GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
           NULL);
 
+  /* under fremantle the dialog does not have an "Open" button */
+  /* as it's closed when a project is being selected */
   gtk_dialog_set_default_response(GTK_DIALOG(context->dialog), 
 				  GTK_RESPONSE_ACCEPT);
 
